Re-exports
pub use config::BatchConfig;pub use config::DoubleCheckConfig;pub use config::DoubleCheckMode;pub use config::FallbackScope;pub use config::JsonMode;pub use config::ModelEndpoint;pub use config::ModelRouteConfig;pub use config::PromptVersion;pub use config::ProviderErrorKind;pub use config::ProviderPreset;pub use config::ProviderPresetResolved;pub use config::ProviderPresetRuntimeOverrides;pub use config::ProviderRequestMetric;pub use config::ProviderRuntimeConfig;pub use config::QaRunConfig;pub use config::ResolvedRunSettings;pub use config::RetryAfterPolicy;pub use config::SegmentationConfig;pub use config::TranslationConfig;pub use config::TranslationProfile;pub use config::cap_output_tokens;pub use entity::Entity;pub use entity::EntityGender;pub use entity::entities_fingerprint;pub use entity::merge_scope_entities;pub use entity::render_entity_agreement_block;pub use error::BookforgeError;pub use error::Result;pub use glossary::GlossaryCandidate;pub use glossary::GlossaryCategory;pub use glossary::GlossaryFormat;pub use glossary::GlossaryPromptTerm;pub use glossary::GlossaryScopeKind;pub use glossary::GlossaryStatus;pub use glossary::GlossaryTerm;pub use glossary::SegmentGlossarySelections;pub use glossary::extract_glossary_candidates;pub use glossary::merge_scope_terms;pub use glossary::select_glossary_for_segments;pub use glossary::target_matches;pub use glossary::term_matches;pub use progress::NullProgressSink;pub use progress::ProgressEvent;pub use progress::ProgressSink;pub use progress::now_ms;pub use run_snapshot::ResolvedRunSettingsSnapshot;pub use run_snapshot::RunConfigSnapshot;pub use scheduler::SchedulerConfig;pub use style::DoNotFields;pub use style::RegisterFields;pub use style::StyleSheet;pub use style::VoiceFields;pub use style::merge_style_sheets;pub use style::render_style_block;pub use style::style_fingerprint;
Modules
- config
- entity
- Named entities — a structured extension of the glossary for characters, places, and named items whose grammatical gender matters in the target language.
- error
- glossary
- ir
- marker
- progress
- run_
snapshot - scheduler
- segment
- style
- Style sheets — per-book/series/global rendering hints injected into the translation prompt.