pub struct RegisterFields {
pub narration: Option<String>,
pub narration_tense: Option<String>,
pub dialogue_default: Option<String>,
pub loanword_policy: Option<String>,
}Expand description
Narrative register: maps to source-language → target-language voice
conventions. Values are strings so the user can pick conventions
outside this enum (passato_remoto etc.) without us pre-enumerating
every target-language idiom.
Fields
narration: Option<String>narration_tense: Option<String>dialogue_default: Option<String>loanword_policy: Option<String>Trait Implementations
Sourceimpl Clone for RegisterFields
impl Clone for RegisterFields
Sourcefn clone(&self) -> RegisterFields
fn clone(&self) -> RegisterFields
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisterFields
impl Debug for RegisterFields
Sourceimpl Default for RegisterFields
impl Default for RegisterFields
Sourcefn default() -> RegisterFields
fn default() -> RegisterFields
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RegisterFields
impl<'de> Deserialize<'de> for RegisterFields
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RegisterFields
Sourceimpl PartialEq for RegisterFields
impl PartialEq for RegisterFields
Sourcefn eq(&self, other: &RegisterFields) -> bool
fn eq(&self, other: &RegisterFields) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RegisterFields
impl Serialize for RegisterFields
impl StructuralPartialEq for RegisterFields